import Vue from "vue";
import Axios from "./AxiosCfg";
import Qs from "qs";
import {
    Loading
} from "element-ui";

let loading; //加载框
let lock = false; //重复提交锁

/**
 * 打开加载框
 */
function openLoad() {
    //关闭加载框
    if (loading != null) loading.close();
    //打开加载框
    loading = Loading.service({
        text: "正在加载",
        target: document.querySelector("#loading-area")
    });
}

/**
 * 关闭加载框
 */
function closeLoad(withLock) {
    if (withLock === true) lock = false;
    //关闭加载框
    loading.close();
}

/**
 * Post请求
 */
Vue.prototype.Post = function (url, data) {
    if (lock) return;
    lock = true;//加锁
    //打开加载框
    openLoad();
    //发送请求
    return new Promise((resolve, reject) => {
        Axios.post(url, Qs.stringify(data))
            .then(res => {
                resolve(res);
            })
            .catch(res => {
                if (typeof reject == 'function') {
                    reject(res);
                }
                console.log(res);
            })
            .finally(() => {
                //关闭加载框
                closeLoad(true);
            })
    });
};
/**
 * Get请求
 */
Vue.prototype.Get = function (url, data) {
    //打开加载框
    openLoad();
    //请求数据
    return new Promise((resolve, reject) => {
        Axios.get(url, {
            params: data
        })
            .then(function (res) {
                closeLoad(); //关闭加载框
                resolve(res);
            })
            .catch((res) => {
                if (typeof reject == 'function') {
                    reject(res);
                }
                console.log(res);
                closeLoad(); //关闭加载框
            })
            .finally(() => {
                //关闭加载框
                closeLoad(true);
            })
    });
};

/**
 * 下载
 */
Vue.prototype.Download = function (url, data, fileName) {
    Axios.post(url, Qs.stringify(data), {
        responseType: "blob"
    }).then(res => {
        let link = document.createElement("a");
        link.style.display = "none";
        link.href = window.URL.createObjectURL(new Blob([res]));
        link.setAttribute("download", fileName); // 自定义下载文件名（如exemple.txt）
        document.body.appendChild(link);
        link.click();
        URL.revokeObjectURL(link.href); // 释放URL 对象
        document.body.removeChild(link);
    });
};
